@@ -209,6 +209,9 @@ class Collection(object):
     def ensure_index(self, *args, **kwargs):
         raise exceptions.NotImplementedError()
 
+    def drop_indexes(self, *args, **kwargs):
+        raise exceptions.NotImplementedError()
+
     def object_id(self, *args, **kwargs):
         return self.owner.object_id(*args, **kwargs)
 
@@ -261,7 +264,25 @@ class MongoCollection(Collection):
 
     def ensure_index(self, *args, **kwargs):
         self.log("ensure_index", *args, **kwargs)
-        return mongo._store_ensure_index(self._base, *args, **kwargs)
+        direction = kwargs.pop("direction", True)
+
+        is_simple = direction == "simple"
+        is_all = direction == "all"
+        is_multiple = isinstance(direction, (list, tuple))
+        is_direction = not is_all and not is_simple and\
+            (legacy.is_string(direction) or type(direction) == int)
+        is_single = is_simple or is_direction
+
+        if is_all: kwargs["directions"] = "all"
+        if is_multiple: kwargs["directions"] = direction
+        if is_direction: args = list(args); args[0] = [(args[0], direction)]
+
+        if is_single: return mongo._store_ensure_index(self._base, *args, **kwargs)
+        else: return mongo._store_ensure_index_many(self._base, *args, **kwargs)
+
+    def drop_indexes(self, *args, **kwargs):
+        self.log("drop_indexes", *args, **kwargs)
+        return self._base.drop_indexes()
 
 class TinyCollection(Collection):
 
@@ -333,6 +354,9 @@ class TinyCollection(Collection):
     def ensure_index(self, *args, **kwargs):
         self.log("ensure_index", *args, **kwargs)
 
+    def drop_indexes(self, *args, **kwargs):
+        self.log("drop_indexes", *args, **kwargs)
+
     def _to_condition(self, filter):
         import tinydb
         query = tinydb.Query()
