@@ -883,9 +883,7 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
 
     @classmethod
     def setup(cls):
-        indexes = cls.indexes()
-        collection = cls._collection()
-        for index in indexes: collection.ensure_index(index)
+        cls._build_indexes()
 
     @classmethod
     def teardown(cls):
@@ -1024,6 +1022,43 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
             default = _type._default() if hasattr(_type, "_default") else default
             return default
 
+    @classmethod
+    def to_description(cls, name):
+        """
+        Converts the provided model attribute/field name into a
+        description ready to be human readable.
+
+        This conversion process may be automated (simple string
+        based replacement) or manually guided (through
+        configuration).
+
+        These strings should be english readable.
+        Some of the process involves caching for performance
+        reasons (avoids multiple description computation).
+
+        :type name: String
+        :param name: The name of the attribute/field to retrieve
+        the human readable description.
+        :rtype: String
+        :return: The human readable version of the attribute or
+        field name according to automated or manual rules.
+        """
+
+        # tries to retrieve the info dictionary for the attribute
+        # name and then uses it to retrieve the possible manual
+        # description value for the field, returning immediately
+        # the value if there's success
+        info = getattr(cls, name) if hasattr(cls, name) else dict()
+        description = info.get("description", None)
+        if description: return description
+
+        # because there's no explicit description defined
+        # runs the automatic underscore to readable conversion
+        # and sets the value on the field info dictionary
+        description = util.underscore_to_readable(name, capitalize = True)
+        info["description"] = description
+        return description
+
     @classmethod
     def all_parents(cls):
         # in case the all parents are already "cached" in the current
@@ -1121,9 +1156,9 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         # definition and check if their are of type index
         for name in definition:
             _definition = cls.definition_n(name)
-            is_index = _definition.get("index", False)
-            if not is_index: continue
-            indexes.append(name)
+            direction = _definition.get("index", False)
+            if not direction: continue
+            indexes.append((name, direction))
 
         # saves the index list under the class and then
         # returns the sequence to the caller method
@@ -1274,21 +1309,62 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         kwargs[name] = filter
 
     @classmethod
-    def is_attached(self):
+    def is_abstract(cls):
+        return False
+
+    @classmethod
+    def is_attached(cls):
         return True
 
+    @classmethod
+    def is_concrete(cls):
+        if not "is_abstract" in cls.__dict__: return True
+        return not cls.is_abstract()
+
+    @classmethod
+    def assert_is_concrete_g(cls):
+        if cls.is_concrete(): return
+        raise exceptions.OperationalError(
+            message = "Model is not concrete",
+            code = 412
+        )
+
     @classmethod
     def _build(cls, model, map):
         pass
 
     @classmethod
     def _meta(cls, model, map):
-        for key, value in legacy.eager(model.items()):
+        # iterates over the complete set of keys and values for the
+        # current model map to try to compute the associated meta value
+        # for all of its attributes (should use some computation)
+        for key, value in legacy.items(model):
+            # verifies if the current value in iteration is either
+            # unset (none) or an unloaded  reference, if that's the
+            # case the value is considered "invalid" not to be encoded
+            is_reference = isinstance(value, TYPE_REFERENCES)
+            is_invalid = value == None or\
+                (is_reference and not value.is_resolved())
+
+            # retrieves the definition for the current key in iteration
+            # so that it's possible to apply the mapper
             definition = cls.definition_n(key)
+
+            # resolves the proper meta value for the key, meaning that if
+            # the type of the current field is a class all the mro of it
+            # is going to be percolated trying to find the best meta value,
+            # and then tries to retrieve the associated mapper function
             meta = cls._solve(key)
             mapper = METAS.get(meta, None)
-            if mapper and not value == None: value = mapper(value, definition)
-            else: value = value if value == None else legacy.UNICODE(value)
+
+            # in case there's a valid mapper function and the value is not
+            # invalid calls the proper mapper function otherwise runs the
+            # default (fallback) operation for meta retrieval
+            if mapper and not is_invalid: value = mapper(value, definition)
+            else: value = value if is_invalid else legacy.UNICODE(value)
+
+            # sets the final meta value in the model, so that it may be
+            # latter retrieved.
             model[key + "_meta"] = value
 
     @classmethod
@@ -1326,6 +1402,11 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         name = cls.__name__.lower()
         return name
 
+    @classmethod
+    def _readable(cls):
+        camel = cls.__name__
+        return util.camel_to_readable(camel, capitalize = True)
+
     @classmethod
     def _eager(cls, model, names):
         # verifies if the provided model instance is a sequence and if
@@ -1585,6 +1666,18 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         })
         return value["seq"]
 
+    @classmethod
+    def _build_indexes(cls):
+        indexes = cls.indexes()
+        collection = cls._collection()
+        for index, direction in indexes:
+            collection.ensure_index(index, direction = direction)
+
+    @classmethod
+    def _destroy_indexes(cls):
+        collection = cls._collection()
+        collection.drop_indexes()
+
     @classmethod
     def _eager_b(cls, eager):
         """
@@ -1788,6 +1881,10 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
             code = 412
         )
 
+    def assert_is_concrete(self):
+        cls = self.__class__
+        cls.assert_is_concrete_g()
+
     def save(
         self,
         validate = True,
@@ -1803,6 +1900,10 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         post_create = True,
         post_update = True
     ):
+        # ensures that the current instance is associated with
+        # a concrete model, ready to be persisted in database
+        self.assert_is_concrete()
+
         # checks if the instance to be saved is a new instance
         # or if this is an update operation and then determines
         # series of default values taking that into account
@@ -1859,6 +1960,10 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         return self
 
     def delete(self, pre_delete = True, post_delete = True):
+        # ensures that the current instance is associated with
+        # a concrete model, ready to be persisted in database
+        self.assert_is_concrete()
+
         # calls the complete set of event handlers for the current
         # delete operation, this should trigger changes in the model
         pre_delete and self.pre_delete()
@@ -2156,7 +2261,7 @@ class LocalModel(Model):
     """
 
     @classmethod
-    def is_attached(self):
+    def is_attached(cls):
         return False
 
 class Field(dict):
@@ -2248,7 +2353,7 @@ class Operation(Action):
 
     pass
 
-def link(name = None, parameters = ()):
+def link(name = None, parameters = (), devel = False):
     """
     Decorator function to be used to "annotate" the provided
     function as an link (string) that is able to change the user
@@ -2263,6 +2368,9 @@ def link(name = None, parameters = ()):
     :type parameters: Tuple
     :param parameters: The sequence containing tuples that describe
     the various parameters to be send to the link.
+    :type devel: bool
+    :param devel: If the link should only be used/available under
+    development like environments (eg: debugging purposes).
     :rtype: Function
     :return: The decorator function that is going to be used to
     generated the final function to be called.
@@ -2272,7 +2380,8 @@ def link(name = None, parameters = ()):
         function._link = Link(
             method = function.__name__,
             name = name or function.__name__,
-            parameters = parameters
+            parameters = parameters,
+            devel = devel
         )
         return function
 
