@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -483,6 +483,37 @@ class ModelTest(unittest.TestCase):
     def test_meta(self):
         self.assertEqual(appier.Model._to_meta(str), "string")
         self.assertEqual(appier.Model._to_meta(bool), "bool")
+        self.assertEqual(appier.Model._to_meta(list), "list")
+        self.assertEqual(appier.Model._to_meta(dict), "map")
         self.assertEqual(appier.Model._to_meta("text"), "text")
         self.assertEqual(appier.Model._to_meta("longtext"), "longtext")
+        self.assertEqual(appier.Model._to_meta("longmap"), "longmap")
         self.assertEqual(appier.Model._to_meta(mock.Person.father["type"]), "reference")
+
+    def test_meta_map(self):
+        method = appier.model.METAS["map"]
+
+        map = dict(hello = "world")
+        result = method(map, {})
+
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "{\"hello\": \"world\"}")
+
+        map = dict(mundo = "olá")
+
+        self.assertEqual(type(result), str)
+        self.assertEqual(method(map, {}), "{\"mundo\": \"olá\"}")
+
+    def test_meta_longmap(self):
+        method = appier.model.METAS["longmap"]
+
+        map = dict(hello = "world")
+        result = method(map, {})
+
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "{\"hello\": \"world\"}")
+
+        map = dict(mundo = "olá")
+
+        self.assertEqual(type(result), str)
+        self.assertEqual(method(map, {}), "{\"mundo\": \"olá\"}")
