@@ -46,8 +46,9 @@ from . import crypt
 from . import legacy
 from . import common
 from . import storage
+from . import exceptions
 
-class Type(object):
+class AbstractType(object):
 
     def json_v(self, *args, **kwargs):
         return str(self)
@@ -55,7 +56,22 @@ class Type(object):
     def map_v(self, *args, **kwargs):
         return self.json_v()
 
-class File(Type):
+class Type(AbstractType):
+
+    def __init__(self, value):
+        cls = self.__class__
+        self.loads(value)
+
+    def json_v(self, *args, **kwargs):
+        return self.dumps()
+
+    def loads(self, value):
+        raise exceptions.NotImplementedError()
+
+    def dumps(self):
+        raise exceptions.NotImplementedError()
+
+class File(AbstractType):
 
     def __init__(self, file):
         if isinstance(file, legacy.BYTES): self.build_d(file)
@@ -253,7 +269,7 @@ class File(Type):
         if not self.engine: return storage.BaseEngine
         return getattr(storage, self.engine.capitalize() + "Engine")
 
-class Files(Type):
+class Files(AbstractType):
 
     def __init__(self, files):
         if isinstance(files, Files): self.build_i(files)
@@ -334,11 +350,13 @@ class ImageFile(File):
         self._ensure_mime()
 
     def _ensure_size(self):
-        if self.width and self.height: return
+        if hasattr(self, "width") and self.width and\
+            hasattr(self, "height") and self.height: return
         self.width, self.height = self._size()
 
     def _ensure_mime(self):
-        if self.format and self.mime: return
+        if hasattr(self, "format") and self.format and\
+            hasattr(self, "mime") and self.mime: return
         self.format, self.mime = self._mime()
 
     def _size(self):
@@ -346,6 +364,7 @@ class ImageFile(File):
         except: return self._size_default()
 
     def _size_image(self):
+        util.ensure_pip("PIL", package = "pillow")
         import PIL.Image
         if not self.data: return self._size_default()
         buffer = legacy.BytesIO(self.data)
@@ -364,6 +383,7 @@ class ImageFile(File):
         except: return self._mime_default()
 
     def _mime_image(self):
+        util.ensure_pip("PIL", package = "pillow")
         import PIL.Image
         if not self.data: return self._size_default()
         buffer = legacy.BytesIO(self.data)
@@ -426,6 +446,7 @@ def image(width = None, height = None, format = "png"):
             ImageFile.build_t(self, file_t)
 
         def resize(self, data = None):
+            util.ensure_pip("PIL", package = "pillow")
             import PIL.Image
             data = data or self.data
             if not data: return data
@@ -459,6 +480,7 @@ def image(width = None, height = None, format = "png"):
             return False
 
         def _resize(self, image, size):
+            util.ensure_pip("PIL", package = "pillow")
             import PIL.Image
 
             # unpacks the provided tuple containing the size dimension into the
@@ -524,7 +546,7 @@ def images(width = None, height = None, format = "png"):
 
     return _ImageFiles
 
-class Reference(Type):
+class Reference(AbstractType):
     pass
 
 def reference(target, name = None, dumpall = False):
@@ -699,7 +721,7 @@ def reference(target, name = None, dumpall = False):
 
     return _Reference
 
-class References(Type):
+class References(AbstractType):
     pass
 
 def references(target, name = None, dumpall = False):
@@ -817,7 +839,7 @@ def references(target, name = None, dumpall = False):
 
     return _References
 
-class Encrypted(Type):
+class Encrypted(AbstractType):
 
     PADDING = ":encrypted"
 
