@@ -651,7 +651,7 @@ def camel_to_underscore(camel, separator = "_"):
     value = value.lower()
     return value
 
-def camel_to_readable(camel):
+def camel_to_readable(camel, capitalize = False):
     """
     Converts the given camel cased oriented string value
     into a readable one meaning that the returned value
@@ -663,14 +663,40 @@ def camel_to_readable(camel):
     :type camel: String
     :param camel: The camel case string value that is going
     to be used in the conversion into a readable string.
+    :type capitalize: bool
+    :param capitalize: If all of the words should be capitalized
+    or if instead only the first one should.
     :rtype: String
     :return: The final human readable string that may be
     used to display a value to an end user.
     """
 
     underscore = camel_to_underscore(camel)
+    return underscore_to_readable(underscore, capitalize = capitalize)
+
+def underscore_to_readable(underscore, capitalize = False):
+    """
+    Converts the given underscore oriented string value
+    into a readable one meaning that the returned value
+    is a set of strings separated by spaces.
+
+    This method may be used to class attributes into
+    something that is readable by an end user.
+
+    :type camel: String
+    :param camel: The underscore string value that is going
+    to be used in the conversion into a readable string.
+    :type capitalize: bool
+    :param capitalize: If all of the words should be capitalized
+    or if instead only the first one should.
+    :rtype: String
+    :return: The final human readable string that may be
+    used to display a value to an end user.
+    """
+
     parts = underscore.split("_")
-    parts[0] = parts[0].title()
+    if capitalize: parts = [part.title() for part in parts]
+    else: parts[0] = parts[0].title()
     return " ".join(parts)
 
 def quote(value, *args, **kwargs):
@@ -1041,7 +1067,11 @@ def load_form(form):
     # linear version of the attribute names
     return form_s
 
-def check_login(token = None, request = None):
+def check_login(self, token = None, request = None):
+    # tries to retrieve the request from the current context
+    # in case it has not been passed through other manner
+    request = request or self.request
+
     # retrieves the data type of the token and creates the
     # tokens sequence value taking into account its type
     token_type = type(token)
@@ -1066,7 +1096,7 @@ def check_login(token = None, request = None):
     # validation procedures have passed the check is valid
     return True
 
-def ensure_login(self, function, token = None, request = None):
+def ensure_login(self, token = None, request = None):
     request = request or self.request
     is_auth = "username" in request.session
     if not is_auth: raise exceptions.AppierException(
@@ -1112,7 +1142,7 @@ def private(function):
     def _private(self, *args, **kwargs):
         ensure = kwargs.get("ensure", True)
         request = kwargs.get("request", self.request)
-        if ensure: ensure_login(self, function, request = request)
+        if ensure: ensure_login(self, request = request)
         sanitize(function, kwargs)
         return function(self, *args, **kwargs)
 
@@ -1128,7 +1158,6 @@ def ensure(token = None):
             request = kwargs.get("request", self.request)
             if ensure: ensure_login(
                 self,
-                function,
                 token = token,
                 request = request
             )
